boofun.analysis.restrictions
============================

.. automodule:: boofun.analysis.restrictions


   .. rubric:: Functions

   .. autosummary::

      apply_restriction
      average_restricted_decision_tree_depth
      batch_random_restrictions
      min_fixing_to_constant
      random_restriction
      restriction_shrinkage
      restriction_to_inputs
      shift_by_mask
      switching_lemma_probability

   .. rubric:: Classes

   .. autosummary::

      Restriction
